.. _donate-page:

=======================
 How to Help Further ?
=======================

If you like PyMetrology, you can donate for its developement to my `PayPal account
<https://www.paypal.me/FabriceSalvaire>`_.

This budget could help me to mainly finance a domain, a vps to host a site, a forum (*) and also to
participate to conference on open source Electronic Design Automation.

(*) This web site is actually hosted on my vps, which is quite loaded.  I don't use hosting site
since it is easier to update the documentation using my own infrastructure.
